@@ -7,11 +7,12 @@
 from mobile_control.mobile_platform import MobilePlatform
 from mobile_control.position_mode import PositionMode
 from mobile_control.velocity_mode import VelocityMode
-from mobile_control.pose import Pose
-from mobile_control.pose import Pose as Velocity
+from mobile_control.planar_pose import PlanarPose
+from mobile_control.planar_pose import PlanarPose as Velocity
 from mobile_control.system_defs import States, StateEvents, \
     Modes, ModeEvents, MotionGeneratorStates, TIMEOUT_INF
 from math import radians
 
+
 def toRadians(degrees):
     return [radians(x) for x in degrees]
