@@ -30,7 +30,8 @@ class MobilePlatform(object):
         return self.switchToLogicState(self.__req, timeout_sec, States.OFF_S, "Off state")
 
     def acknowledge(self, timeout_sec=TIMEOUT_INF):
-        return False
+        self.__req.setParameter(MobilePlatform.LOGIC_STATE_COMMAND, StateEvents.ACKNOWLEDGE.value).get()
+        return self.switchToLogicState(self.__req, timeout_sec, States.OFF_S, "Off state")
 
     def velocityMode(self, timeout_sec=TIMEOUT_INF):
         self.__req.setParameter(MobilePlatform.LOGIC_MODE_COMMAND, ModeEvents.GOTO_VELOCITY.value).get()
