@@ -6,18 +6,29 @@
 #
 
 import time
+from .system_defs import SHORT_SLEEP_SEC
 
 
 class VelocityMode(object):
+    """VelocityMode is an object that allows the mobile platform to be controlled in velocity mode
+    """
+
     TARGET_VELOCITY = "root/Control/hostInTargetVelocity"
     ACTUAL_VELOCITY_POLAR = "root/Control/VelocityIntegrator/velocityOutPolar"
     ACTUAL_VELOCITY_CARTESIAN = "root/Control/VelocityIntegrator/velocityOut"
-    SHORT_SLEEP_SEC = 0.01
 
     def __init__(self, req):
         self.__req = req
 
     def setVelocity(self, vel, timeout_sec=0):
+        """VelocityMode controls the robot in velocity mode
+            Args:
+                vel(Velocity): target velocity
+
+            Returns:
+                status of the command execution.
+        """
+
         if timeout_sec == 0:
             return self.__req.setParameter(VelocityMode.TARGET_VELOCITY, [vel.x(), vel.y(), vel.rz()])
 
@@ -28,13 +39,23 @@ class VelocityMode(object):
             t1 = time.time()
             timeout_sec -= (t1 - t0)
             if timeout_sec >= 0:
-                time.sleep(VelocityMode.SHORT_SLEEP_SEC)
-                timeout_sec -= VelocityMode.SHORT_SLEEP_SEC
+                time.sleep(SHORT_SLEEP_SEC)
+                timeout_sec -= SHORT_SLEEP_SEC
 
         return status
 
     def getTargetVelocity(self):
+        """Gets the current target velocity
+            Returns:
+                target velocity.
+
+        """
         return self.__req.getParameter(VelocityMode.TARGET_VELOCITY).get().value
 
     def getActualVelocity(self):
+        """Gets the actual velocity
+            Returns:
+                actual velocity.
+
+        """
         return self.__req.getParameter(VelocityMode.ACTUAL_VELOCITY_POLAR).get().value
